#!/usr/bin/env perl 
# ACL:license
#  ----------------------------------------------------------------------
#  This software and ancillary information (herein called "SOFTWARE")
#  called POOMA (Parallel Object-Oriented Methods and Applications) is
#  made available under the terms described here.  The SOFTWARE has been
#  approved for release with associated LA-CC Number LA-CC-98-65.
#  
#  Unless otherwise indicated, this SOFTWARE has been authored by an
#  employee or employees of the University of California, operator of the
#  Los Alamos National Laboratory under Contract No.  W-7405-ENG-36 with
#  the U.S. Department of Energy.  The U.S. Government has rights to use,
#  reproduce, and distribute this SOFTWARE, and to allow others to do so.
#  The public may copy and use this SOFTWARE, FOR NONCOMMERCIAL USE ONLY,
#  without charge, provided that this Notice and any statement of
#  authorship are reproduced on all copies.  Neither the Government nor
#  the University makes any warranty, express or implied, or assumes any
#  liability or responsibility for the use of this SOFTWARE.
#  
#  If SOFTWARE is modified to produce derivative works, such modified
#  SOFTWARE should be clearly marked, so as not to confuse it with the
#  version available from LANL.
#  
#  For more information about POOMA, send e-mail to pooma@acl.lanl.gov,
#  or visit the POOMA web page at http://www.acl.lanl.gov/pooma/.
#  ----------------------------------------------------------------------
# ACL:license

#
# laa, 10-March-1998
#
# Create make-related resources for an existing project.
###############################################################################

$PROGRAM     = $0; $PROGRAM =~ s/.*\/(.*)$/$1/;
$DATE        = `date`; chomp $DATE;

$mode = shift @ARGV;
if    ($mode =~ /^newuser$/i) { # Create user preferences file
	($ufile, $user_pref_name) = @ARGV;
	&write_user_prefs_file ($ufile, $user_pref_name);
}
elsif ($mode =~ /^newproject$/i) { # Create new project???
	print "mode=$mode not yet implemented.";
	exit;
}
else {
	print "Unrecognized mode for $PROGRAM. Exiting.\n";
	exit;
}

###############################################################################
sub write_user_prefs_file {
($ufile, $user_pref_name) = @_;

if (-e $ufile) {
  print "Your user prefs file '$ufile' already exists. Exiting.\n";
  exit;
}

open (MK, ">$ufile") || die "Couldn't open $ufile for writing\n";
print MK <<EOF;
# Generated by $PROGRAM, $DATE
# Use this file to set or override make variables set in other 
# parts of the make system. Inclusion of this file in keyed on
# the environment variable USER_PREF_NAME.
#
# PLEASE DON'T override make variables set in the SUITE files. 

# COPY stderr & stdout INFO_FILE
#SUITE_REDIRECT      = 2>&1 | tee -a \$(INFO_FILE)

# REDIRECT stderr & stdout INFO_FILE (this is the default in the include.tail.mk file)
#SUITE_REDIRECT      = >> \$(INFO_FILE) 2>&1

# Allow stderr & stdout to come only to the screen
#SUITE_REDIRECT      = 

# Set options for xterm, for use with "WATCH=x"
#WATCH_OPTS          = -geom 155x50 -sb -sl 1000
 
ifndef LD_PARALLEL
LD_PARALLEL := 8
endif

default::

# Sample rule
hello:
	\@echo Hello \$(USER_PREF_NAME)
EOF
close MK;
}

# ACL:rcsinfo
#  ----------------------------------------------------------------------
#  $RCSfile: new.pl,v $   $Author: julianc $
#  $Revision: 1.7 $   $Date: 1999/07/21 22:19:34 $
#  ----------------------------------------------------------------------
# ACL:rcsinfo
